@@ -5,9 +5,13 @@ logging.basicConfig()
 logger = logging.getLogger("duckietown-tokens ")
 logger.setLevel(logging.INFO)
 
-__version__ = "6.0.5"
+__version__ = "6.0.9"
 
-logger.info("duckietown-tokens %s" % __version__)
+import os
+
+path = os.path.dirname(os.path.dirname(__file__))
+
+logger.debug(f"duckietown-tokens version {__version__} path {path}")
 
 from .duckietown_tokens import *
 from .tokens_cli import *
